@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "inf-clojure" "3.4.0"
+(define-package "inf-clojure" "20260220.1437"
   "Basic interaction with a Clojure REPL."
   '((emacs        "28.1")
     (clojure-mode "5.11"))
   :url "https://github.com/clojure-emacs/inf-clojure"
-  :commit "4d3b8fae32caf91e0f9432004bbe861f54ce9c0c"
-  :revdesc "4d3b8fae32ca"
+  :commit "be5e9bd90775b35c8bc2ecb118d6af9a521b2d81"
+  :revdesc "be5e9bd90775"
   :keywords '("processes" "comint" "clojure")
   :maintainers '(("Bozhidar Batsov" . "bozhidar@batsov.dev")))
